Skip to contents

Get the catalog backend type of an attached lake

Usage

get_ducklake_backend(ducklake_name = NULL)

Arguments

ducklake_name

Name of the lake to look up. When NULL (the default), the lake the session is currently USEing is looked up.

Value

One of "duckdb", "postgres", "sqlite", or "mysql". Defaults to "duckdb" when the lake is unknown.

Examples

if (FALSE) { # \dontrun{
attach_ducklake("my_lake", lake_path = "~/data/lake")
get_ducklake_backend()
#> [1] "duckdb"

# With several lakes attached, look one up by name
get_ducklake_backend("my_sqlite_lake")
} # }