Skip to contents

Installs the Quack DuckDB extension, which provides the quack: client-server protocol. Quack is a core extension from DuckDB 1.5.3 onward, so it is autoloaded the first time it is used. Installing it ahead of time is useful on machines that have no internet access at query time.

Usage

install_quack(load = TRUE)

Arguments

load

If TRUE (the default), load the extension after installing it.

Value

Invisibly, NULL. Called for its side effect of installing the quack DuckDB extension into the local extension cache.

Examples

if (FALSE) { # \dontrun{
install_quack()
} # }