Clears a table's declared sort order so newly written data files are no longer sorted. Existing files are unaffected.
See also
Other sorting:
set_table_sorting()
Clears a table's declared sort order so newly written data files are no longer sorted. Existing files are unaffected.
Other sorting:
set_table_sorting()