Retrieves information about available snapshots/versions for a table.
Details
This function queries the snapshot history of a table, showing available versions and their timestamps. This is useful for understanding what historical versions are available for time-travel queries.
See also
Other time travel:
get_ducklake_table_asof(),
get_ducklake_table_version(),
get_table_changes(),
restore_table_version()