Show the SQL that would be executed by ducklake operations
Source:R/show_ducklake_query.R
show_ducklake_query.RdThis function shows the SQL that would be generated and executed by ducklake. This is useful for debugging and understanding what SQL is being sent to DuckDB.
See also
Other table operations:
create_table(),
ducklake_exec(),
get_ducklake_table(),
get_metadata_table(),
replace_table()
Examples
if (FALSE) { # \dontrun{
# Show SQL for an update operation (table name inferred)
get_ducklake_table("my_table") |>
mutate(status = "updated") |>
show_ducklake_query()
} # }